#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup


setup(name='asynchw',
      version='0.0.1',
      description='More stuff coming',
      author='Olli Paloviita',
      author_email=None,
      url=None,
      py_modules=['asynchw'],
     )
